@@ -99,5 +99,5 @@
  * Since: 2019.3
  */
 #ifndef __GI_SCANNER__
-#define OSTREE_BUILT_FEATURES "inode64 initial-var libcurl libsoup3 gpgme ex-fsverity libarchive openssl sign-ed25519 sign-spki avahi libmount release p2p"
+#define OSTREE_BUILT_FEATURES "inode64 initial-var libcurl libsoup3 gpgme ex-fsverity selinux openssl sign-ed25519 sign-spki release p2p"
 #endif
